@@ -495,9 +495,7 @@ class WinOSClient:
         cmd = f'Select-String -Path {path_} -Pattern "{pattern}"'
         if case_sensitive:
             cmd += ' -CaseSensitive'
-
         cmd += ' | ConvertTo-Json'
-        print(cmd)
 
         result = self.run_ps(cmd)
         result = self._convert_result(result, key='Filename')
@@ -685,7 +683,7 @@ class WinOSClient:
             dst: Destination root directory. e:\zen.txt,, e:\dir1
         """
 
-        cmd = f'Copy-Item -Path "{src}" -Destination "{dst}" -Force'
+        cmd = f'Move-Item -Path "{src}" -Destination "{dst}" -Force'
         result = self.run_ps(cmd)
         return result.ok
 
